/*
Copyright The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
// Code generated by client-gen. DO NOT EDIT.

package v1beta1

import (
	"context"
	"time"

	v1beta1 "github.com/loggie-io/loggie/pkg/discovery/kubernetes/apis/loggie/v1beta1"
	scheme "github.com/loggie-io/loggie/pkg/discovery/kubernetes/client/clientset/versioned/scheme"
	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// ClusterLogConfigsGetter has a method to return a ClusterLogConfigInterface.
// A group's client should implement this interface.
type ClusterLogConfigsGetter interface {
	ClusterLogConfigs() ClusterLogConfigInterface
}

// ClusterLogConfigInterface has methods to work with ClusterLogConfig resources.
type ClusterLogConfigInterface interface {
	Create(ctx context.Context, clusterLogConfig *v1beta1.ClusterLogConfig, opts v1.CreateOptions) (*v1beta1.ClusterLogConfig, error)
	Update(ctx context.Context, clusterLogConfig *v1beta1.ClusterLogConfig, opts v1.UpdateOptions) (*v1beta1.ClusterLogConfig, error)
	UpdateStatus(ctx context.Context, clusterLogConfig *v1beta1.ClusterLogConfig, opts v1.UpdateOptions) (*v1beta1.ClusterLogConfig, error)
	Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
	Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.ClusterLogConfig, error)
	List(ctx context.Context, opts v1.ListOptions) (*v1beta1.ClusterLogConfigList, error)
	Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.ClusterLogConfig, err error)
	ClusterLogConfigExpansion
}

// clusterLogConfigs implements ClusterLogConfigInterface
type clusterLogConfigs struct {
	client rest.Interface
}

// newClusterLogConfigs returns a ClusterLogConfigs
func newClusterLogConfigs(c *LoggieV1beta1Client) *clusterLogConfigs {
	return &clusterLogConfigs{
		client: c.RESTClient(),
	}
}

// Get takes name of the clusterLogConfig, and returns the corresponding clusterLogConfig object, and an error if there is any.
func (c *clusterLogConfigs) Get(ctx context.Context, name string, options v1.GetOptions) (result *v1beta1.ClusterLogConfig, err error) {
	result = &v1beta1.ClusterLogConfig{}
	err = c.client.Get().
		Resource("clusterlogconfigs").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do(ctx).
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of ClusterLogConfigs that match those selectors.
func (c *clusterLogConfigs) List(ctx context.Context, opts v1.ListOptions) (result *v1beta1.ClusterLogConfigList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1beta1.ClusterLogConfigList{}
	err = c.client.Get().
		Resource("clusterlogconfigs").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do(ctx).
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested clusterLogConfigs.
func (c *clusterLogConfigs) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Resource("clusterlogconfigs").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch(ctx)
}

// Create takes the representation of a clusterLogConfig and creates it.  Returns the server's representation of the clusterLogConfig, and an error, if there is any.
func (c *clusterLogConfigs) Create(ctx context.Context, clusterLogConfig *v1beta1.ClusterLogConfig, opts v1.CreateOptions) (result *v1beta1.ClusterLogConfig, err error) {
	result = &v1beta1.ClusterLogConfig{}
	err = c.client.Post().
		Resource("clusterlogconfigs").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(clusterLogConfig).
		Do(ctx).
		Into(result)
	return
}

// Update takes the representation of a clusterLogConfig and updates it. Returns the server's representation of the clusterLogConfig, and an error, if there is any.
func (c *clusterLogConfigs) Update(ctx context.Context, clusterLogConfig *v1beta1.ClusterLogConfig, opts v1.UpdateOptions) (result *v1beta1.ClusterLogConfig, err error) {
	result = &v1beta1.ClusterLogConfig{}
	err = c.client.Put().
		Resource("clusterlogconfigs").
		Name(clusterLogConfig.Name).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(clusterLogConfig).
		Do(ctx).
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (c *clusterLogConfigs) UpdateStatus(ctx context.Context, clusterLogConfig *v1beta1.ClusterLogConfig, opts v1.UpdateOptions) (result *v1beta1.ClusterLogConfig, err error) {
	result = &v1beta1.ClusterLogConfig{}
	err = c.client.Put().
		Resource("clusterlogconfigs").
		Name(clusterLogConfig.Name).
		SubResource("status").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(clusterLogConfig).
		Do(ctx).
		Into(result)
	return
}

// Delete takes name of the clusterLogConfig and deletes it. Returns an error if one occurs.
func (c *clusterLogConfigs) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error {
	return c.client.Delete().
		Resource("clusterlogconfigs").
		Name(name).
		Body(&opts).
		Do(ctx).
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *clusterLogConfigs) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error {
	var timeout time.Duration
	if listOpts.TimeoutSeconds != nil {
		timeout = time.Duration(*listOpts.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Resource("clusterlogconfigs").
		VersionedParams(&listOpts, scheme.ParameterCodec).
		Timeout(timeout).
		Body(&opts).
		Do(ctx).
		Error()
}

// Patch applies the patch and returns the patched clusterLogConfig.
func (c *clusterLogConfigs) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.ClusterLogConfig, err error) {
	result = &v1beta1.ClusterLogConfig{}
	err = c.client.Patch(pt).
		Resource("clusterlogconfigs").
		Name(name).
		SubResource(subresources...).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(data).
		Do(ctx).
		Into(result)
	return
}
